@@ -19,6 +19,8 @@
 -- Maintainer  : Brendan Hay <brendan.g.hay@gmail.com>
 -- Stability   : experimental
 -- Portability : non-portable (GHC extensions)
+--
+-- Derived from AWS service descriptions, licensed under Apache 2.0.
 
 module Network.AWS.CodeDeploy.Types
     (
@@ -216,7 +218,7 @@ module Network.AWS.CodeDeploy.Types
 import Data.Char (isUpper)
 import Network.AWS.Error
 import Network.AWS.Prelude
-import Network.AWS.Signing.V4
+import Network.AWS.Signing
 import qualified GHC.Exts
 
 -- | Version @2014-10-06@ of the Amazon CodeDeploy service.
@@ -227,8 +229,7 @@ instance AWSService CodeDeploy where
     type Er CodeDeploy = JSONError
 
     service = Service
-        { _svcEndpoint     = regional
-        , _svcAbbrev       = "CodeDeploy"
+        { _svcAbbrev       = "CodeDeploy"
         , _svcPrefix       = "codedeploy"
         , _svcVersion      = "2014-10-06"
         , _svcTargetPrefix = Just "CodeDeploy_20141006"
@@ -240,9 +241,9 @@ instance AWSService CodeDeploy where
 data GenericRevisionInfo = GenericRevisionInfo
     { _griDeploymentGroups :: List "deploymentGroups" Text
     , _griDescription      :: Maybe Text
-    , _griFirstUsedTime    :: Maybe ISO8601
-    , _griLastUsedTime     :: Maybe ISO8601
-    , _griRegisterTime     :: Maybe ISO8601
+    , _griFirstUsedTime    :: Maybe POSIX
+    , _griLastUsedTime     :: Maybe POSIX
+    , _griRegisterTime     :: Maybe POSIX
     } deriving (Eq, Ord, Show)
 
 -- | 'GenericRevisionInfo' constructor.
@@ -310,7 +311,7 @@ instance ToJSON GenericRevisionInfo where
 data ApplicationInfo = ApplicationInfo
     { _aiApplicationId   :: Maybe Text
     , _aiApplicationName :: Maybe Text
-    , _aiCreateTime      :: Maybe ISO8601
+    , _aiCreateTime      :: Maybe POSIX
     , _aiLinkedToGitHub  :: Maybe Bool
     } deriving (Eq, Ord, Show)
 
@@ -400,8 +401,8 @@ instance ToJSON BundleType where
     toJSON = toJSONText
 
 data TimeRange = TimeRange
-    { _trEnd   :: Maybe ISO8601
-    , _trStart :: Maybe ISO8601
+    { _trEnd   :: Maybe POSIX
+    , _trStart :: Maybe POSIX
     } deriving (Eq, Ord, Show)
 
 -- | 'TimeRange' constructor.
@@ -473,7 +474,7 @@ instance ToJSON DeploymentCreator where
 data InstanceSummary = InstanceSummary
     { _isDeploymentId    :: Maybe Text
     , _isInstanceId      :: Maybe Text
-    , _isLastUpdatedAt   :: Maybe ISO8601
+    , _isLastUpdatedAt   :: Maybe POSIX
     , _isLifecycleEvents :: List "lifecycleEvents" LifecycleEvent
     , _isStatus          :: Maybe InstanceStatus
     } deriving (Eq, Show)
@@ -1167,8 +1168,8 @@ instance ToJSON SortOrder where
 
 data DeploymentInfo = DeploymentInfo
     { _diApplicationName               :: Maybe Text
-    , _diCompleteTime                  :: Maybe ISO8601
-    , _diCreateTime                    :: Maybe ISO8601
+    , _diCompleteTime                  :: Maybe POSIX
+    , _diCreateTime                    :: Maybe POSIX
     , _diCreator                       :: Maybe DeploymentCreator
     , _diDeploymentConfigName          :: Maybe Text
     , _diDeploymentGroupName           :: Maybe Text
@@ -1178,7 +1179,7 @@ data DeploymentInfo = DeploymentInfo
     , _diErrorInformation              :: Maybe ErrorInformation
     , _diIgnoreApplicationStopFailures :: Maybe Bool
     , _diRevision                      :: Maybe RevisionLocation
-    , _diStartTime                     :: Maybe ISO8601
+    , _diStartTime                     :: Maybe POSIX
     , _diStatus                        :: Maybe DeploymentStatus
     } deriving (Eq, Show)
 
@@ -1349,9 +1350,9 @@ instance ToJSON DeploymentInfo where
 
 data LifecycleEvent = LifecycleEvent
     { _leDiagnostics        :: Maybe Diagnostics
-    , _leEndTime            :: Maybe ISO8601
+    , _leEndTime            :: Maybe POSIX
     , _leLifecycleEventName :: Maybe Text
-    , _leStartTime          :: Maybe ISO8601
+    , _leStartTime          :: Maybe POSIX
     , _leStatus             :: Maybe LifecycleEventStatus
     } deriving (Eq, Show)
 
@@ -1548,7 +1549,7 @@ instance ToJSON ErrorCode where
     toJSON = toJSONText
 
 data DeploymentConfigInfo = DeploymentConfigInfo
-    { _dciCreateTime           :: Maybe ISO8601
+    { _dciCreateTime           :: Maybe POSIX
     , _dciDeploymentConfigId   :: Maybe Text
     , _dciDeploymentConfigName :: Maybe Text
     , _dciMinimumHealthyHosts  :: Maybe MinimumHealthyHosts
